Components.utils.import("resource://gre/modules/Services.jsm");
Components.utils.import("resource://gre/modules/l10nHelper.jsm");
Components.utils.import("resource://gre/modules/prompterHelper.jsm");

function Startup()
{
  //window.sizeToContent();
  GetUIElements();
}
